/*******************************************************************************
* File Name: CapSlider.c
* Version 1.30
*
* Description:
*  This file provides the source code to the API for the CapSense Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CapSlider.h"

CapSlider_Slot CapSlider_ScanSlotTable[] = 
{
    {0, 0, 1, 0, 0},
    {1, 1, 1, 0, 0},
    {2, 2, 1, 0, 0},
    {3, 3, 1, 0, 0},
    {4, 4, 1, 0, 0}
};

const uint8 CapSlider_IndexTable[] = { 0x00 };

CapSlider_CSD_Settings CapSlider_SettingsTable[] = 
{
    {CapSlider_IDAC_RANGE_32uA, 20, CapSlider_PWM_RESOLUTION_8_BITS, CapSlider_SCAN_SPEED_ULTRA_FAST, CapSlider_DISABLE_STATE_GND},
    {CapSlider_IDAC_RANGE_32uA, 20, CapSlider_PWM_RESOLUTION_8_BITS, CapSlider_SCAN_SPEED_ULTRA_FAST, CapSlider_DISABLE_STATE_GND},
    {CapSlider_IDAC_RANGE_32uA, 20, CapSlider_PWM_RESOLUTION_8_BITS, CapSlider_SCAN_SPEED_ULTRA_FAST, CapSlider_DISABLE_STATE_GND},
    {CapSlider_IDAC_RANGE_32uA, 20, CapSlider_PWM_RESOLUTION_8_BITS, CapSlider_SCAN_SPEED_ULTRA_FAST, CapSlider_DISABLE_STATE_GND},
    {CapSlider_IDAC_RANGE_32uA, 20, CapSlider_PWM_RESOLUTION_8_BITS, CapSlider_SCAN_SPEED_ULTRA_FAST, CapSlider_DISABLE_STATE_GND}
};

const CapSlider_PortShift CapSlider_PortShiftTable[] = 
{
    {CapSlider_sbCSD_cPort__LS_Slider1_e0__PORT, CapSlider_sbCSD_cPort__LS_Slider1_e0__SHIFT},
    {CapSlider_sbCSD_cPort__LS_Slider1_e1__PORT, CapSlider_sbCSD_cPort__LS_Slider1_e1__SHIFT},
    {CapSlider_sbCSD_cPort__LS_Slider1_e2__PORT, CapSlider_sbCSD_cPort__LS_Slider1_e2__SHIFT},
    {CapSlider_sbCSD_cPort__LS_Slider1_e3__PORT, CapSlider_sbCSD_cPort__LS_Slider1_e3__SHIFT},
    {CapSlider_sbCSD_cPort__LS_Slider1_e4__PORT, CapSlider_sbCSD_cPort__LS_Slider1_e4__SHIFT}
};

uint8 CapSlider_status = 0;

uint8 CapSlider_idacInitVar = 0;

uint16 CapSlider_SlotResult[CapSlider_TOTAL_SCANSLOT_COUNT] = {0};
uint16 *CapSlider_SlotRaw = CapSlider_SlotResult;


/*******************************************************************************
* Function Name: CapSlider_Start
********************************************************************************
*
* Summary:
*  Initializes registers for each module and starts the component. This function
*  calls functions automatically depending on modules selected in the
*  customizer. This function should be called prior to calling any other
*  component functions.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_Start(void)
{
    CapSlider_CSD_Start();
}


/*******************************************************************************
* Function Name: CapSlider_Stop
********************************************************************************
*
* Summary:
*  Stops the slot scanner, disables interrupts, and resets all slots to an 
*  inactive state
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_Stop(void)
{
    CapSlider_CSD_Stop();
}


/*******************************************************************************
* Function Name: CapSlider_ScanSlot
********************************************************************************
*
* Summary:
*  Calls the function CapSlider_CSD_ScanSlot and scans defined scan slot.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_ScanSlot(uint8 slot)
{
      CapSlider_CSD_ScanSlot(slot);
}


/*******************************************************************************
* Function Name: CapSlider_ScanAllSlots
********************************************************************************
*
* Summary:
*  Scans all slots by calling CapSlider_CSD_ScanAllSlots function for method
*  selected in customizer.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_ScanAllSlots(void)
{
    CapSlider_CSD_ScanAllSlots();
}


/*******************************************************************************
* Function Name: CapSlider_sbCSD_cIDAC_SetValue
********************************************************************************
*
* Summary:
*  Sets DAC value
*
* Parameters:
*  value:  Sets DAC value between 0 and 255.
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_sbCSD_cIDAC_SetValue(uint8 value)
{
    /*  Set Value  */
    CapSlider_IDAC_DATA = value;
    
    #if defined(CapSlider_IDAC_FIRST_SILICON)
        CapSlider_IDAC_DATA = value;        /*  TODO: Need for first version of silicon */
    #endif
}


/*******************************************************************************
* Function Name: CapSlider_sbCSD_cIDAC_DacTrim
********************************************************************************
*
* Summary:
*  Sets the trim value for the given range.
*
* Parameters:
*  value:  Sets DAC value between 0 and 255.
* 
* Return:
*  void
*
*******************************************************************************/
void CapSlider_sbCSD_cIDAC_DacTrim(void)
{
    uint8 mode;
    
    mode = ((CapSlider_IDAC_CR0 & CapSlider_IDAC_RANGE_MASK) >> 1);
    if((CapSlider_IDAC_IDIR_MASK & CapSlider_IDAC_CR1) == CapSlider_IDAC_IDIR_SINK)
    {
        mode++;
    }
    
    CapSlider_IDAC_TR = CY_GET_XTND_REG8((uint8 *)(CapSlider_DAC_TRIM_BASE + mode));
}


/*******************************************************************************
* Function Name: CapSlider_sbCSD_cIDAC_Start
********************************************************************************
*
* Summary:
*  Sets power level then turn on IDAC8.
*
* Parameters:
*  power:  Sets power level between off (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_sbCSD_cIDAC_Start(void)
{
    /* Hardware initiazation only needs to occure the first time */
    if ( CapSlider_idacInitVar == 0)
    {
        CapSlider_idacInitVar = 1;
        
        CapSlider_IDAC_CR0 = CapSlider_IDAC_MODE_I;
        
        CapSlider_IDAC_CR1 = CapSlider_IDAC_IDIR_SRC | CapSlider_IDAC_IDIR_CTL_UDB;
        
        CapSlider_sbCSD_cIDAC_SetValue(CapSlider_TURN_OFF_IDAC);
        
        CapSlider_sbCSD_cIDAC_DacTrim();
    }
    
    /* Enable power to DAC */
    CapSlider_IDAC_PWRMGR |= CapSlider_IDAC_ACT_PWR_EN;
}


/*******************************************************************************
* Function Name: CapSlider_sbCSD_cIDAC_Stop
********************************************************************************
*
* Summary:
*  Powers down IDAC8 to lowest power state.
*
* Parameters:
*   void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_sbCSD_cIDAC_Stop(void)
{
    #if defined(CapSlider_IDAC_FIRST_SILICON)
        /* TODO: Work around for IDAC */
        /* De-initiaize the IDAC */
        CapSlider_idacInitVar = 0;
        
        /* Change IDAC to VDAC mode */
        CapSlider_IDAC_CR0 &= ~CapSlider_IDAC_MODE_I;
    #endif
    
    /* Disble power to DAC */
    CapSlider_IDAC_PWRMGR &= ~CapSlider_IDAC_ACT_PWR_EN;
}


/*******************************************************************************
* Function Name: CapSlider_sbCSD_cIDAC_SetRange
********************************************************************************
*
* Summary:
*  Sets current range
*
* Parameters:
*  Range:  Sets on of four valid ranges.
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_sbCSD_cIDAC_SetRange(uint8 range)
{
    /* Clear existing mode */
    CapSlider_IDAC_CR0 &= ~CapSlider_IDAC_RANGE_MASK; 
    
    /*  Set Range  */
    CapSlider_IDAC_CR0 |= ( range & CapSlider_IDAC_RANGE_MASK );
    CapSlider_sbCSD_cIDAC_DacTrim();
}


/*******************************************************************************
* Function Name: CapSlider_CSD_Start
********************************************************************************
*
* Summary:
*  Initializes registers and starts the CapSense Component.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_Start(void)
{
    /* Setup DIG_CLK_DivSerial */
    CapSlider_sUDBSpeed_Start();
    
    /* Setup sbCSD_csRawCnt */
    CapSlider_sbCSD_cRAW_Start();
    
    /* Setup sbCSD_csPWM */
    CapSlider_sbCSD_cPWM_Start();
    
    /* Enable Comparator */
    CapSlider_sbCSD_cComp_Start();
    
    /* Initialize AMux */
    CapSlider_sbCSD_cAMux_Start();
    
    /* Start Idac */
    CapSlider_sbCSD_cIDAC_Start();
    
    /* Connect Cmod, Cmp, Idac */
    CapSlider_sbCSD_cAMux_Connect(CapSlider_CMOD_CHANNEL);
    CapSlider_sbCSD_cAMux_Connect(CapSlider_CMP_VP_CHANNEL);
    
    CapSlider_sbCSD_cAMux_Connect(CapSlider_IDAC_CHANNEL);
    
    /* Clear all Sensor */
    CapSlider_CSD_ClearSlots();
    
    /* Setup ISR Component for CapSense */
    CyIntDisable(CapSlider_ISR_NUMBER);
    CyIntSetVector(CapSlider_ISR_NUMBER, CapSlider_ISR);
    CyIntSetPriority(CapSlider_ISR_NUMBER, CapSlider_ISR_PRIORITY);
    CyIntEnable(CapSlider_ISR_NUMBER);
    
    /* Enable csBuf */
    CapSlider_CSBUF_PWRMGR |= CapSlider_CSBUF_PWR_ENABLE;
    CapSlider_CAPS_CFG0 |= CapSlider_CSBUF_ENABLE;
}


/*******************************************************************************
* Function Name: CapSlider_CSD_Stop
********************************************************************************
*
* Summary:
*  Stops the slot scanner, disables internal interrupts, and calls 
*  CSD_ClearSlots() to reset all slots to an inactive state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_Stop(void)
{
    /* Stop Capsensing */
    CapSlider_CONTROL &= ~CapSlider_START_CAPSENSING;
    
    /* Disable the CapSense interrupt */
    CyIntEnable(CapSlider_ISR_NUMBER);
    
    /* Clear all Sensor */
    CapSlider_CSD_ClearSlots();
    
    /* Disable Comparator */
    CapSlider_sbCSD_cComp_Stop();
    
    /* Disable power to IDAC */
    CapSlider_sbCSD_cIDAC_Stop();
    
    /* Disable csBuf */
    CapSlider_CAPS_CFG0 &= ~CapSlider_CSBUF_ENABLE;
    CapSlider_CSBUF_PWRMGR &= ~CapSlider_CSBUF_PWR_ENABLE;
}


/*******************************************************************************
* Function Name: CapSlider_CSD_ScanSlot
********************************************************************************
*
* Summary:
*  Sets scan settings and scans the selected scan slot. Each scan slot has
*  a unique number within the slot array. This number is assigned by the
*  CapSense customizer in sequence.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_ScanSlot(uint8 slot)
{
    uint8 i, s, state;
    uint8 maxSns = CapSlider_ScanSlotTable[slot].SnsCnt;
    uint8 startIndex = CapSlider_ScanSlotTable[slot].IndexOffset;
    uint8 rawIndex = CapSlider_ScanSlotTable[slot].RawIndex; 
    
    /* Set Slot Settings */
    CapSlider_CSD_SetSlotSettings(slot);
    
    /* Disable CapSense Buffer */
    CapSlider_CAPS_CFG0 &= ~CapSlider_CSBUF_ENABLE;    
    
    /* Enable Sensors */
    if (maxSns == CapSlider_ALONE_SENSOR)
    {
        CapSlider_CSD_EnableSensor(startIndex);
    }
    else
    {
        for(i=0; i < maxSns; i++)
        {
            s = CapSlider_IndexTable[startIndex+i];
            CapSlider_CSD_EnableSensor(s);
        }
    }
    
    /* Set Flag CapSensing in progres */
    CapSlider_status |= CapSlider_START_CAPSENSING;
    
    /* Start PWM One Shout and PRS at one time */
    CapSlider_CONTROL |= CapSlider_START_CAPSENSING;
    
    /* Wait for finish CapSensing */
    while (CapSlider_status == CapSlider_START_CAPSENSING)
    { ; }
    
    /* Stop Capsensing */
    CapSlider_CONTROL &= ~CapSlider_START_CAPSENSING;
    
    /* Read SlotResult from RawCnt */
    CapSlider_SlotResult[rawIndex] = CapSlider_sbCSD_cRAW_ReadCounter();
    
    /* Disable Sensors */
    state = CapSlider_SettingsTable[slot].DisableState;
    if (maxSns == CapSlider_ALONE_SENSOR)
    {
        CapSlider_CSD_DisableSensor(startIndex, state);
    }
    else
    {
        for(i=0; i < maxSns; i++)
        {
            s = CapSlider_IndexTable[startIndex+i];
            CapSlider_CSD_DisableSensor(s, state);
        }
    }
    
    /* Turn off IDAC */
    CapSlider_sbCSD_cIDAC_SetValue(CapSlider_TURN_OFF_IDAC);
    
    /* Enable Vref on AMUX */
    CapSlider_CAPS_CFG0 |= CapSlider_CSBUF_ENABLE;
}


/*******************************************************************************
* Function Name: CapSlider_CSD_ScanAllSlots
********************************************************************************
*
* Summary:
*  Scans all scan slots by callingCapSlider_CSD_ScanSlot for each
*  slot index.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_ScanAllSlots(void)
{
    uint8 i;
    
    for(i=0; i < CapSlider_TOTAL_SCANSLOT_COUNT;i++)
    {
         CapSlider_CSD_ScanSlot(i);
    }
}


/*******************************************************************************
* Function Name: CapSlider_CSD_SetSlotSettings
********************************************************************************
*
* Summary:
*  Sets the scan settings of selected scan slot. Each setting has a unique
*  number within the settings array and is connected to corresponding scan slot.
*  This number is assigned by the CapSense customizer in sequence.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_SetSlotSettings(uint8 slot)
{
    uint8 scanSpeed = CapSlider_SettingsTable[slot].ScanSpeed;
    uint16 resolution = ((uint16) CapSlider_SettingsTable[slot].Resolution << CapSlider_PWM_WINDOW_SHIFT)\
                        | CapSlider_PWM_RESOLUTION_16_BITS;
    uint8 idacRange = CapSlider_SettingsTable[slot].IdacRange;
    uint8 idacSettings = CapSlider_SettingsTable[slot].IdacSettings;
    
    /* PWM Resolution */
    CapSlider_sbCSD_cPWM_WritePeriod(resolution);
    CapSlider_sbCSD_cPWM_WriteCompare(resolution);
    
    /* Reset RawCnt and rearm PWM */
    CapSlider_CONTROL |= CapSlider_RESET_PWM_CNTR;
    
    /* Set ScanSpeed */
    CapSlider_sUDBSpeed_Stop();
    CapSlider_sUDBSpeed_WriteCounter(scanSpeed);
    CapSlider_sUDBSpeed_WritePeriod(scanSpeed);
    CapSlider_sUDBSpeed_Start();
    
    CapSlider_CONTROL &= ~CapSlider_RESET_PWM_CNTR;
    
    /* Set Idac */
    CapSlider_sbCSD_cIDAC_SetRange(idacRange);
    CapSlider_sbCSD_cIDAC_SetValue(idacSettings);
}


/*******************************************************************************
* Function Name: CapSlider_CSD_ClearSlots
********************************************************************************
*
* Summary:
*  Clears all slots to the non-sampling state by sequentially disconnecting all
*  slots from Analog MUX Bus, disable pin global control and connecting them to
*  GND or Shield electrode.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_ClearSlots(void)
{
    uint8 i, s, j;
    uint8 startIndex, maxSns, state;
    
    for (i=0; i < CapSlider_TOTAL_SCANSLOT_COUNT; i++)
    {
        startIndex = CapSlider_ScanSlotTable[i].IndexOffset;
        maxSns = CapSlider_ScanSlotTable[i].SnsCnt;
        state = CapSlider_SettingsTable[i].DisableState;
        
        /* Disable Sensors */
        if (maxSns == CapSlider_ALONE_SENSOR)
        {
            CapSlider_CSD_DisableSensor(startIndex, state);
        }
        else
        {
            for(j=0; j < maxSns; j++)
            {
                s = CapSlider_IndexTable[startIndex+j];
                CapSlider_CSD_DisableSensor(s, state);
            }
        }
    }
}


/*******************************************************************************
* Function Name: CapSlider_CSD_ReadSlot
********************************************************************************
*
* Summary:
*  Returns scan slot raw data from the SlotResult[] array. Each scan slot has a
*  unique number within the slot array. This number is assigned by the CapSense
*  customizer in sequence.
*
* Parameters:
*  slot:  Scan slot number
*
* Return:
*  Returns current raw data value for defined scan slot
*
*******************************************************************************/
uint16 CapSlider_CSD_ReadSlot(uint8 slot)
{
    uint8 index = CapSlider_ScanSlotTable[slot].RawIndex;
    
    return CapSlider_SlotResult[index];
}


/*******************************************************************************
* Function Name: CapSlider_CSD_EnableSensor
********************************************************************************
*
* Summary:
*  Configures the selected sensor to measure during the next measurement cycle.
*  The corresponding pins are set to Analog High-Z mode and connected to the
*  Analog Mux Bus. This also enables the comparator function.
*
* Parameters:
*  sensor:  Sensor number
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_EnableSensor(uint8 sensor)
{
    uint8 port = CapSlider_PortShiftTable[sensor].port;
    uint8 shift = CapSlider_PortShiftTable[sensor].shift;
    uint8 mask = 1;
    
    mask <<= shift;
    
    /* Make sensor High-Z */
    *(CapSlider_BASE_PRT_PC + (CapSlider_PRT_PC_OFFSET*port) + shift) = CapSlider_PRT_PC_HIGHZ;
    
    /* Connect from DSI output */
    *(CapSlider_BASE_PRTDSI_CAPS + (CapSlider_PRTDSI_OFFSET*port)) |= mask;
    
    /* Connect to AMUX */
    CapSlider_sbCSD_cAMux_Connect(sensor);    
}


/*******************************************************************************
* Function Name: CapSlider_CSD_DisableSensor
********************************************************************************
*
* Summary:
*  Disables the selected sensor. The corresponding pin is disconnected from the
*  Analog Mux Bus and connected to GND, High_Z or Shield electrode.
*
* Parameters:
*  sensor:  Sensor number
*  state:  State of sensor when disabled
*
* Return:
*  void
*
*******************************************************************************/
void CapSlider_CSD_DisableSensor(uint8 sensor, uint8 state)
{
    uint8 port = CapSlider_PortShiftTable[sensor].port;
    uint8 shift = CapSlider_PortShiftTable[sensor].shift;
    uint8 mask = 1;
    
    mask <<= shift;
    
    /* Disconnect from AMUX */
    CapSlider_sbCSD_cAMux_Disconnect(sensor);
    
    /* Connect from DSI output */
    *(CapSlider_BASE_PRTDSI_CAPS + (CapSlider_PRTDSI_OFFSET*port)) &= ~mask;
    
    switch(state)
    {
        case CapSlider_DISABLE_STATE_GND:
            *(CapSlider_BASE_PRT_PC + (CapSlider_PRT_PC_OFFSET*port) + shift) = CapSlider_PRT_PC_GND;
        break;
        
        case CapSlider_DISABLE_STATE_HIGHZ:
            *(CapSlider_BASE_PRT_PC + (CapSlider_PRT_PC_OFFSET*port) + shift) = CapSlider_PRT_PC_HIGHZ;
        break;
        
        case CapSlider_DISABLE_STATE_SHIELD:
            *(CapSlider_BASE_PRT_PC + (CapSlider_PRT_PC_OFFSET*port) + shift) = CapSlider_PRT_PC_SHIELD;
        break;
        
        default:
            *(CapSlider_BASE_PRT_PC + (CapSlider_PRT_PC_OFFSET*port) + shift) = CapSlider_PRT_PC_GND;
        break;
    }
}


/* [] END OF FILE */
