/*******************************************************************************
* File Name: CapSlider.h
* Version 1.30
*
* Description:
*  This file provides constants and parameter values for the CapSense
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAPSENSE_CapSlider_H)
#define CY_CAPSENSE_CapSlider_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cydevice_trm.h"
#include "CyLib.h"

#include "CapSlider_sbCSD_cRAW.h"
#include "CapSlider_sbCSD_cComp.h"
#include "CapSlider_sbCSD_cAMux.h"
#include "CapSlider_sbCSD_cPWM.h"
#include "CapSlider_sUDBSpeed.h"


/***************************************
*       Types definition
***************************************/

/*       Scan Slot struct             */
typedef struct _CapSlider_Slot
{
    uint8 RawIndex;         /* Entry in SlotResult */
    uint8 IndexOffset;      /* Offset in IndezTable */
    uint8 SnsCnt;           /* Number of Sensors in currect Slot */
    uint8 WidgetNumber;     /* Number of Widget this slot belongs */
    uint8 DebounceCount;    /* Helps to define if slot Active */
} CapSlider_Slot;

/*        Settings for CSD         */
typedef struct _CapSlider_CSD_Settings
{
    uint8 IdacRange;            /* 1-3 range exist, multiplier for IDAC */
    uint8 IdacSettings;         /* IDAC settings for measurament */
    uint8 Resolution;           /* PWM Resolution */
    uint8 ScanSpeed;            /* Speed of scanning  DIG_CLK */
    uint8 DisableState;         /* Disable state of ScanSlot */

} CapSlider_CSD_Settings;

/*       Port Shift struct            */
typedef struct _CapSlider_PortShift
{
    uint8 port;
    uint8 shift;
} CapSlider_PortShift;


/***************************************
*        Function Prototypes
***************************************/

void CapSlider_Start(void);
void CapSlider_Stop(void);
void CapSlider_ScanSlot(uint8 slot);
void CapSlider_ScanAllSlots(void);

void CapSlider_CSD_Start(void);
void CapSlider_CSD_Stop(void);
void CapSlider_CSD_ScanSlot(uint8 slot);
void CapSlider_CSD_ScanAllSlots(void);
void CapSlider_CSD_SetSlotSettings(uint8 slot);
void CapSlider_CSD_ClearSlots(void);
void CapSlider_CSD_EnableSensor(uint8 sensor);
void CapSlider_CSD_DisableSensor(uint8 sensor, uint8 state);
uint16 CapSlider_CSD_ReadSlot(uint8 slot);
/* Interrupt handler */
CY_ISR_PROTO(CapSlider_ISR);

extern uint8 CapSlider_status;


/***************************************
*           API Constants
***************************************/

#define CapSlider_TOTAL_SENSOR_COUNT              5
#define CapSlider_TOTAL_SCANSLOT_COUNT            5
#define CapSlider_TOTAL_GENERIC_SCANSLOT_COUNT    0

/* Define Sensors */
#define CapSlider_SENSOR_LS_SLIDER1_E0    0
#define CapSlider_SENSOR_LS_SLIDER1_E1    1
#define CapSlider_SENSOR_LS_SLIDER1_E2    2
#define CapSlider_SENSOR_LS_SLIDER1_E3    3
#define CapSlider_SENSOR_LS_SLIDER1_E4    4

/* Define ScanSlots */
#define CapSlider_SCANSLOT_LS_SLIDER1_E0    0
#define CapSlider_SCANSLOT_LS_SLIDER1_E1    1
#define CapSlider_SCANSLOT_LS_SLIDER1_E2    2
#define CapSlider_SCANSLOT_LS_SLIDER1_E3    3
#define CapSlider_SCANSLOT_LS_SLIDER1_E4    4

/* Chanels of CapSense */
#define CapSlider_CMOD_CHANNEL          5
#define CapSlider_CMP_VP_CHANNEL        6
#define CapSlider_IDAC_CHANNEL          7

#define CapSlider_CSD_METHOD
#define CapSlider_VREF_VDAC_VALUE        64

/* Scan Speed Type */
#define CapSlider_SCAN_SPEED_ULTRA_FAST      0x01u
#define CapSlider_SCAN_SPEED_FAST            0x03u
#define CapSlider_SCAN_SPEED_NORMAL          0x07u
#define CapSlider_SCAN_SPEED_SLOW            0x0Fu

/* Idac SetRange */
#define CapSlider_IDAC_RANGE_MASK            0x0Cu
#define CapSlider_IDAC_RANGE_32uA            0x00u
#define CapSlider_IDAC_RANGE_255uA           0x04u
#define CapSlider_IDAC_RANGE_2mA             0x08u

/* PWM Resolution */
#define CapSlider_PWM_WINDOW_SHIFT           8u
#define CapSlider_PWM_RESOLUTION_8_BITS      0x00u
#define CapSlider_PWM_RESOLUTION_9_BITS      0x01u
#define CapSlider_PWM_RESOLUTION_10_BITS     0x03u
#define CapSlider_PWM_RESOLUTION_11_BITS     0x07u
#define CapSlider_PWM_RESOLUTION_12_BITS     0x0Fu
#define CapSlider_PWM_RESOLUTION_13_BITS     0x1Fu
#define CapSlider_PWM_RESOLUTION_14_BITS     0x3Fu
#define CapSlider_PWM_RESOLUTION_15_BITS     0x7Fu
#define CapSlider_PWM_RESOLUTION_16_BITS     0xFFu

/* Enable csBuffer */
#define CapSlider_CSBUF_BOOST_ENABLE         0x02u
#define CapSlider_CSBUF_ENABLE               0x01u

/* Starts CapSensing */
#define CapSlider_START_CAPSENSING           0x01u

/* Resets PWM and Raw Counter */
#define CapSlider_RESET_PWM_CNTR             0x02u

/* Overfow of counter while CSA */
#define CapSlider_RAW_OVERFLOW               0x04u

/* Turn off IDAC  */
#define CapSlider_TURN_OFF_IDAC              0x00u

/* Rbleed */
#define CapSlider_MAX_RB_NUMBER      3
#define CapSlider_RBLEED1            0
#define CapSlider_RBLEED2            1
#define CapSlider_RBLEED3            2

/* Diasable States */
#define CapSlider_DISABLE_STATE_GND          0
#define CapSlider_DISABLE_STATE_HIGHZ        1
#define CapSlider_DISABLE_STATE_SHIELD       2
#define CapSlider_ALONE_SENSOR               1


/***************************************
*             Registers
***************************************/

/* Control Register */
#define CapSlider_CONTROL             (* (reg8 *) CapSlider_sbCSD_cControl_ctrl_reg__CONTROL_REG )

/* csBuffer */
#define CapSlider_CAPS_CFG0           (* (reg8 *) CapSlider_sbCSD_cBuf__CFG0 )
#define CapSlider_CAPS_CFG1           (* (reg8 *) CapSlider_sbCSD_cBuf__CFG1 )
#define CapSlider_CSBUF_PWRMGR        (* (reg8 *) CapSlider_sbCSD_cBuf__PM_ACT_CFG )
#define CapSlider_CSBUF_PWR_ENABLE    CapSlider_sbCSD_cBuf__PM_ACT_MSK

/* csIdac */
#define CapSlider_IDAC_CR0        (* (reg8 *) CapSlider_sbCSD_cIDAC__CR0 )
#define CapSlider_IDAC_CR1        (* (reg8 *) CapSlider_sbCSD_cIDAC__CR1 )
#define CapSlider_IDAC_DATA       (* (reg8 *) CapSlider_sbCSD_cIDAC__D )
#define CapSlider_IDAC_STROBE     (* (reg8 *) CapSlider_sbCSD_cIDAC__STROBE )
#define CapSlider_IDAC_TR         (* (reg8 *) CapSlider_sbCSD_cIDAC__TR )
#define CapSlider_IDAC_PWRMGR     (* (reg8 *) CapSlider_sbCSD_cIDAC__PM_ACT_CFG )

/* TODO: Remove this line after changes to DAC */
#define CapSlider_IDAC_FIRST_SILICON

/* PM_ACT_CFG (Active Power Mode CFG Register) */ 
#if !defined(CapSlider_IDAC_FIRST_SILICON)
    #define CapSlider_IDAC_ACT_PWR_EN    CapSlider_sbCSD_cIDAC__PM_ACT_MSK
#else
    #define CapSlider_IDAC_ACT_PWR_EN    0xFFu /* TODO: Work around for incorrect power enable */
#endif

/* DAC offset address from CYDEV_FLSHID_BASE */
#define CapSlider_DAC0_OFFSET    0x00011Cu
#define CapSlider_DAC1_OFFSET    0x000112u
#define CapSlider_DAC2_OFFSET    0x000124u
#define CapSlider_DAC3_OFFSET    0x000134u

#define CapSlider_DAC_POS  (CapSlider_sbCSD_cIDAC__D - CYDEV_ANAIF_WRK_DAC0_BASE)

#if(CapSlider_DAC_POS == 0)
    #define CapSlider_DAC_TRIM_BASE    CYDEV_FLSHID_BASE + CapSlider_DAC0_OFFSET
#endif

#if(CapSlider_DAC_POS == 1)
    #define CapSlider_DAC_TRIM_BASE    CYDEV_FLSHID_BASE + CapSlider_DAC1_OFFSET
#endif

#if(CapSlider_DAC_POS == 2)
    #define CapSlider_DAC_TRIM_BASE    CYDEV_FLSHID_BASE + CapSlider_DAC2_OFFSET
#endif

#if(CapSlider_DAC_POS == 3)
    #define CapSlider_DAC_TRIM_BASE    CYDEV_FLSHID_BASE + CapSlider_DAC3_OFFSET
#endif

/* ISR Number and Priority to work with CyLib functions */
#define CapSlider_ISR_NUMBER        CapSlider_sbCSD_cISR__INTC_NUMBER
#define CapSlider_ISR_PRIORITY      CapSlider_sbCSD_cISR__INTC_PRIOR_NUM

#if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
    #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (CapSlider_sbCSD_cISR__ES2_PATCH))
        #include <intrins.h>
        #define CapSlider_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
    #endif
#endif

/* Register to work with port */
#define CapSlider_BASE_PRT_PC            ( (reg8 *) CYDEV_IO_PC_PRT0_BASE )
#if((CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD) && (CYDEV_CHIP_REV_EXPECT == CYDEV_CHIP_REV_LEOPARD_ES1))
    #define CapSlider_BASE_PRTDSI_CAPS   ( (reg8 *) CYREG_PRTDSI_PRT0_CAPS_SEL )
#else
    #define CapSlider_BASE_PRTDSI_CAPS   ( (reg8 *) CYREG_PRT0_CAPS_SEL )
#endif


/***************************************
*       Register Constants
***************************************/

/* PC and CAPS_SEL Registers Offset */
#define CapSlider_PRT_PC_OFFSET      CYDEV_IO_PC_PRT0_SIZE
#define CapSlider_PRTDSI_OFFSET      (CYDEV_PRTDSI_PRT0_SIZE+1)

/* Masks of PTR PC Register */
#define CapSlider_DR_MASK            0x01
#define CapSlider_DM0_MASK           0x02
#define CapSlider_DM1_MASK           0x04
#define CapSlider_DM2_MASK           0x08
#define CapSlider_BYP_MASK           0x80

#define CapSlider_PRT_PC_GND         CapSlider_DM2_MASK
#define CapSlider_PRT_PC_HIGHZ       (CapSlider_DM2_MASK |CapSlider_DR_MASK)
#define CapSlider_PRT_PC_SHIELD      (CapSlider_DM2_MASK | CapSlider_DM1_MASK | CapSlider_BYP_MASK)

/* CR0 Idac Control Register 0 definitions */

/* Bit Field  DAC_MODE */
#define CapSlider_IDAC_MODE_MASK         0x10u
#define CapSlider_IDAC_MODE_V            0x00u
#define CapSlider_IDAC_MODE_I            0x10u

/* CR1 Idac Control Register 1 definitions */

/* Bit Field  DAC_I_DIR */
/* Register control of current direction */
#define CapSlider_IDAC_IDIR_MASK         0x04u
#define CapSlider_IDAC_IDIR_SINK         0x04u
#define CapSlider_IDAC_IDIR_SRC          0x00u

/* Bit Field  DAC_MX_IOFF_SRC */
/* Selects source of IOFF control, reg or UDB */
#define CapSlider_IDAC_IDIR_CTL_MASK     0x02u
#define CapSlider_IDAC_IDIR_CTL_REG      0x00u
#define CapSlider_IDAC_IDIR_CTL_UDB      0x02u

#endif /* End CY_CAPSENSE_CapSlider_H */


 /* [] END OF FILE */
